@@ -56,3 +56,23 @@ const QString MyAction::getSkinPath()
     return this->mSkinPath;
 }
 
+void MyAction::setSkinClass(const SkinClass skinClass)
+{
+    this->mSkinClass = skinClass;
+}
+
+const SkinClass MyAction::getSkinClass()
+{
+    return this->mSkinClass;
+}
+
+void MyAction::setMyActionType(const MyActionType myActionType)
+{
+    this->mMyActionType = myActionType;
+}
+
+const MyActionType MyAction::getMyActionType()
+{
+    return this->mMyActionType;
+}
+
