@@ -23,6 +23,21 @@
 #include <QAction>
 #include "kimpanelagent.h"
 
+typedef enum MyActionType
+{
+    IMAction,
+    StatusAction,
+    VKAction,
+    SkinAction,
+    MozcHiraganaAction,
+    MozcToolAction,
+} MyActionType;
+
+typedef enum SkinClass
+{
+    FCITX,
+} SkinClass;
+
 class MyAction : public QAction
 {
     Q_OBJECT
@@ -37,11 +52,17 @@ public:
     const KimpanelProperty& getProp();
     void setSkinPath(const QString skinPath);
     const QString getSkinPath();
+    void setSkinClass(const SkinClass skinClass);
+    const SkinClass getSkinClass();
+    void setMyActionType(const MyActionType myActionType);
+    const MyActionType getMyActionType();
 
 private:
 
     KimpanelProperty mProp;
     QString mSkinPath;
+    SkinClass mSkinClass;
+    MyActionType mMyActionType;
 };
 
 #endif // __MY_ACTION_H__
